@@ -16,8 +16,10 @@
 #include "asyncresult.h"
 #include "cancellable.h"
 #include "drive.h"
+#include "error.h"
 #include "file.h"
-#include "fileattribute.h"
+#include "fileattributeinfo.h"
+#include "fileattributeinfolist.h"
 #include "fileenumerator.h"
 #include "fileicon.h"
 #include "fileinfo.h"
@@ -49,6 +51,7 @@ GType g_file_info_get_type(void);
 GType g_file_input_stream_get_type(void);
 GType g_file_monitor_get_type(void);
 GType g_file_output_stream_get_type(void);
+GType g_filter_input_stream_get_type(void);
 GType g_input_stream_get_type(void);
 GType g_mount_operation_get_type(void);
 GType g_output_stream_get_type(void);
@@ -57,6 +60,7 @@ GType g_volume_monitor_get_type(void);
 
 //Declarations of the *_error_quark() functions:
 
+GQuark g_io_error_quark(void);
 } // extern "C"
 
 
@@ -70,6 +74,7 @@ namespace Gio {  class FileInfo_Class { public: static Glib::ObjectBase* wrap_ne
 namespace Gio {  class FileInputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class FileMonitor_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class FileOutputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gio {  class FilterInputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class InputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class MountOperation_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class OutputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -81,6 +86,7 @@ namespace Gio {
 void wrap_init()
 {
   // Register Error domains:
+  Glib::Error::register_domain(g_io_error_quark(), &Gio::Error::throw_func);
 
 // Map gtypes to gtkmm wrapper-creation functions:
   Glib::wrap_register(g_app_launch_context_get_type(), &Gio::AppLaunchContext_Class::wrap_new);
@@ -91,6 +97,7 @@ void wrap_init()
   Glib::wrap_register(g_file_input_stream_get_type(), &Gio::FileInputStream_Class::wrap_new);
   Glib::wrap_register(g_file_monitor_get_type(), &Gio::FileMonitor_Class::wrap_new);
   Glib::wrap_register(g_file_output_stream_get_type(), &Gio::FileOutputStream_Class::wrap_new);
+  Glib::wrap_register(g_filter_input_stream_get_type(), &Gio::FilterInputStream_Class::wrap_new);
   Glib::wrap_register(g_input_stream_get_type(), &Gio::InputStream_Class::wrap_new);
   Glib::wrap_register(g_mount_operation_get_type(), &Gio::MountOperation_Class::wrap_new);
   Glib::wrap_register(g_output_stream_get_type(), &Gio::OutputStream_Class::wrap_new);
@@ -106,6 +113,7 @@ void wrap_init()
   Gio::FileInputStream::get_type();
   Gio::FileMonitor::get_type();
   Gio::FileOutputStream::get_type();
+  Gio::FilterInputStream::get_type();
   Gio::InputStream::get_type();
   Gio::MountOperation::get_type();
   Gio::OutputStream::get_type();
