@@ -32,6 +32,7 @@ int main (int argc, char** argv)
             << get_defs(G_TYPE_FILE_ENUMERATOR)
             << get_defs(G_TYPE_FILE_INFO)
             << get_defs(G_TYPE_FILE_ICON)
+            << get_defs(G_TYPE_FILE_MONITOR)
 //            << get_defs(G_TYPE_FILE_ATTRIBUTE_INFO_LIST)
 //            << get_defs(G_TYPE_FILE_ATTRIBUTE_MATCHER)
             << get_defs(G_TYPE_FILE_INPUT_STREAM)
@@ -39,6 +40,7 @@ int main (int argc, char** argv)
 
             << get_defs(G_TYPE_INPUT_STREAM)
             << get_defs(G_TYPE_LOADABLE_ICON)
+            << get_defs(G_TYPE_MOUNT)
             << get_defs(G_TYPE_MOUNT_OPERATION)
             << get_defs(G_TYPE_SIMPLE_ASYNC_RESULT)
 
